"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("./debug"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const process_1 = __importDefault(require("process"));
const js_yaml_1 = __importDefault(require("js-yaml"));
function determinePackageManager(config) {
    var _a, _b;
    for (const jobDescription of (_b = (_a = config.jobs) === null || _a === void 0 ? void 0 : _a.include) !== null && _b !== void 0 ? _b : []) {
        const { script } = jobDescription;
        for (const command of script !== null && script !== void 0 ? script : []) {
            if (command.startsWith('npm')) {
                return 'npm';
            }
            if (command.startsWith('yarn')) {
                return 'yarn';
            }
        }
    }
    throw new Error('Could not determine a supported package manager from TravisCI configuration');
}
function default_1() {
    var _a;
    const configFile = path_1.default.join(process_1.default.cwd(), '.travis.yml');
    debug_1.default(`Looking for TravisCI configuration at ${configFile}`);
    let configString;
    try {
        configString = fs_1.default.readFileSync(configFile, { encoding: 'utf-8' });
    }
    catch (error) {
        if (error.code === 'ENOENT') {
            debug_1.default('No TravisCI configuration found');
            return null;
        }
        throw error;
    }
    const config = js_yaml_1.default.safeLoad(configString, {
        onWarning: console.log,
    });
    if (typeof config !== 'object') {
        console.error(config);
        throw new Error('Parsing .travis.yml failed');
    }
    const browsers = ['chrome', 'firefox'].filter((_) => Object.keys(config.addons).includes(_));
    const nodeVersion = `${(_a = config.node_js) === null || _a === void 0 ? void 0 : _a[0]}.x`;
    const emberTryScenarios = config.jobs.include
        .map(({ env }) => {
        if (typeof env !== 'string') {
            return null;
        }
        const [key, value] = env.split('=');
        return key === 'EMBER_TRY_SCENARIO' ? value : null;
    })
        .filter((_) => _ !== null);
    const allowedToFailEmberTryScenarios = config.jobs.allow_failures
        .map(({ env }) => {
        if (typeof env !== 'string') {
            return null;
        }
        const [key, value] = env.split('=');
        return key === 'EMBER_TRY_SCENARIO' ? value : null;
    })
        .filter((_) => _ !== null);
    const requiredEmberTryScenarios = emberTryScenarios.filter((scenario) => !allowedToFailEmberTryScenarios.includes(scenario));
    const packageManager = determinePackageManager(config);
    return {
        browsers,
        emberTryScenarios: {
            required: requiredEmberTryScenarios,
            allowedToFail: allowedToFailEmberTryScenarios,
        },
        nodeVersion,
        packageManager,
    };
}
exports.default = default_1;
